#
# PySNMP MIB module MPLS-TE-STD-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/MPLS-TE-STD-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:14:16 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( Integer, ObjectIdentifier, OctetString, ) = mibBuilder.importSymbols("ASN1", "Integer", "ObjectIdentifier", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( SingleValueConstraint, ValueRangeConstraint, ValueSizeConstraint, ConstraintsUnion, ConstraintsIntersection, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "SingleValueConstraint", "ValueRangeConstraint", "ValueSizeConstraint", "ConstraintsUnion", "ConstraintsIntersection")
( IndexIntegerNextFree, ) = mibBuilder.importSymbols("DIFFSERV-MIB", "IndexIntegerNextFree")
( ifCounterDiscontinuityGroup, InterfaceIndexOrZero, ifGeneralInformationGroup, ) = mibBuilder.importSymbols("IF-MIB", "ifCounterDiscontinuityGroup", "InterfaceIndexOrZero", "ifGeneralInformationGroup")
( InetAddressPrefixLength, ) = mibBuilder.importSymbols("INET-ADDRESS-MIB", "InetAddressPrefixLength")
( MplsPathIndexOrZero, TeHopAddressUnnum, MplsTunnelIndex, TeHopAddressType, TeHopAddress, MplsLSPID, mplsStdMIB, MplsBurstSize, MplsBitRate, MplsTunnelInstanceIndex, MplsOwner, MplsExtendedTunnelId, TeHopAddressAS, MplsTunnelAffinity, MplsPathIndex, ) = mibBuilder.importSymbols("MPLS-TC-STD-MIB", "MplsPathIndexOrZero", "TeHopAddressUnnum", "MplsTunnelIndex", "TeHopAddressType", "TeHopAddress", "MplsLSPID", "mplsStdMIB", "MplsBurstSize", "MplsBitRate", "MplsTunnelInstanceIndex", "MplsOwner", "MplsExtendedTunnelId", "TeHopAddressAS", "MplsTunnelAffinity", "MplsPathIndex")
( SnmpAdminString, ) = mibBuilder.importSymbols("SNMP-FRAMEWORK-MIB", "SnmpAdminString")
( ObjectGroup, ModuleCompliance, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ObjectGroup", "ModuleCompliance", "NotificationGroup")
( ModuleIdentity, Bits, MibIdentifier, MibScalar, MibTable, MibTableRow, MibTableColumn, TimeTicks, zeroDotZero, Gauge32, Integer32, ObjectIdentity, iso, Unsigned32, Counter64, NotificationType, Counter32, IpAddress, ) = mibBuilder.importSymbols("SNMPv2-SMI", "ModuleIdentity", "Bits", "MibIdentifier", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "TimeTicks", "zeroDotZero", "Gauge32", "Integer32", "ObjectIdentity", "iso", "Unsigned32", "Counter64", "NotificationType", "Counter32", "IpAddress")
( RowStatus, TextualConvention, RowPointer, TimeStamp, TruthValue, StorageType, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "RowStatus", "TextualConvention", "RowPointer", "TimeStamp", "TruthValue", "StorageType", "DisplayString")
mplsTeStdMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 10, 166, 3)).setRevisions(("2004-06-03 00:00",))
if mibBuilder.loadTexts: mplsTeStdMIB.setLastUpdated('200406030000Z')
if mibBuilder.loadTexts: mplsTeStdMIB.setOrganization('Multiprotocol Label Switching (MPLS) Working Group')
if mibBuilder.loadTexts: mplsTeStdMIB.setContactInfo('        Cheenu Srinivasan\n                     Bloomberg L.P.\n             Email:  cheenu@bloomberg.net\n            \n                     Arun Viswanathan\n                     Force10 Networks, Inc.\n             Email:  arunv@force10networks.com\n            \n                     Thomas D. Nadeau\n                     Cisco Systems, Inc.\n             Email:  tnadeau@cisco.com\n            \n                    Comments about this document should be emailed\n                    directly to the MPLS working group mailing list at\n                    mpls@uu.net.')
if mibBuilder.loadTexts: mplsTeStdMIB.setDescription("Copyright (C) The Internet Society (2004). The\n            initial version of this MIB module was published\n            in RFC 3812. For full legal notices see the RFC\n            itself or see: http://www.ietf.org/copyrights/ianamib.html\n\n            This MIB module contains managed object definitions\n             for MPLS Traffic Engineering (TE) as defined in:\n            1. Extensions to RSVP for LSP Tunnels, Awduche et\n             al, RFC 3209, December 2001\n            2. Constraint-Based LSP Setup using LDP, Jamoussi\n             (Editor), RFC 3212, January 2002\n            3. Requirements for Traffic Engineering Over MPLS,\n             Awduche, D., Malcolm, J., Agogbua, J., O'Dell, M.,\n             and J. McManus, [RFC2702], September 1999")
mplsTeNotifications = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 3, 0))
mplsTeScalars = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 3, 1))
mplsTeObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 3, 2))
mplsTeConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 3, 3))
mplsTunnelConfigured = MibScalar((1, 3, 6, 1, 2, 1, 10, 166, 3, 1, 1), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsTunnelConfigured.setDescription('The number of tunnels configured on this device. A\n             tunnel is considered configured if the\n             mplsTunnelRowStatus is active(1).')
mplsTunnelActive = MibScalar((1, 3, 6, 1, 2, 1, 10, 166, 3, 1, 2), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsTunnelActive.setDescription('The number of tunnels active on this device. A\n            tunnel is considered active if the\n            mplsTunnelOperStatus is up(1).')
mplsTunnelTEDistProto = MibScalar((1, 3, 6, 1, 2, 1, 10, 166, 3, 1, 3), Bits().clone(namedValues=NamedValues(("other", 0), ("ospf", 1), ("isis", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsTunnelTEDistProto.setDescription('The traffic engineering distribution protocol(s)\n            used by this LSR. Note that an LSR may support more\n            than one distribution protocol simultaneously.')
mplsTunnelMaxHops = MibScalar((1, 3, 6, 1, 2, 1, 10, 166, 3, 1, 4), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsTunnelMaxHops.setDescription('The maximum number of hops that can be specified for\n            a tunnel on this device.')
mplsTunnelNotificationMaxRate = MibScalar((1, 3, 6, 1, 2, 1, 10, 166, 3, 1, 5), Unsigned32()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mplsTunnelNotificationMaxRate.setDescription('This variable indicates the maximum number of\n            notifications issued per second. If events occur\n            more rapidly, the implementation may simply fail to\n            emit these notifications during that period, or may\n            queue them until an appropriate time. A value of 0\n            means no throttling is applied and events may be\n            notified at the rate at which they occur.')
mplsTunnelIndexNext = MibScalar((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 1), IndexIntegerNextFree().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsTunnelIndexNext.setDescription('This object contains an unused value for\n            mplsTunnelIndex, or a zero to indicate\n            that none exist. Negative values are not allowed,\n            as they do not correspond to valid values of\n            mplsTunnelIndex.\n\n            Note that this object offers an unused value\n            for an mplsTunnelIndex value at the ingress\n            side of a tunnel. At other LSRs the value\n            of mplsTunnelIndex SHOULD be taken from the\n            value signaled by the MPLS signaling protocol.\n            ')
mplsTunnelTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 2), )
if mibBuilder.loadTexts: mplsTunnelTable.setDescription('The mplsTunnelTable allows new MPLS tunnels to be\n            created between an LSR and a remote endpoint, and\n            existing tunnels to be reconfigured or removed.\n            Note that only point-to-point tunnel segments are\n            supported, although multipoint-to-point and point-\n            to-multipoint connections are supported by an LSR\n            acting as a cross-connect.  Each MPLS tunnel can\n            thus have one out-segment originating at this LSR\n            and/or one in-segment terminating at this LSR.')
mplsTunnelEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 2, 1), ).setIndexNames((0, "MPLS-TE-STD-MIB", "mplsTunnelIndex"), (0, "MPLS-TE-STD-MIB", "mplsTunnelInstance"), (0, "MPLS-TE-STD-MIB", "mplsTunnelIngressLSRId"), (0, "MPLS-TE-STD-MIB", "mplsTunnelEgressLSRId"))
if mibBuilder.loadTexts: mplsTunnelEntry.setDescription('An entry in this table represents an MPLS tunnel.\n            An entry can be created by a network administrator\n            or by an SNMP agent as instructed by an MPLS\n            signalling protocol. Whenever a new entry is\n            created with mplsTunnelIsIf set to true(1), then a\n            corresponding entry is created in ifTable as well\n            (see RFC 2863). The ifType of this entry is\n            mplsTunnel(150).\n\n            A tunnel entry needs to be uniquely identified across\n            a MPLS network. Indices mplsTunnelIndex and\n            mplsTunnelInstance uniquely identify a tunnel on\n            the LSR originating the tunnel.  To uniquely\n            identify a tunnel across an MPLS network requires\n            index mplsTunnelIngressLSRId.  The last index\n            mplsTunnelEgressLSRId is useful in identifying all\n            instances of a tunnel that terminate on the same\n            egress LSR.')
mplsTunnelIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 2, 1, 1), MplsTunnelIndex())
if mibBuilder.loadTexts: mplsTunnelIndex.setDescription('Uniquely identifies a set of tunnel instances\n            between a pair of ingress and egress LSRs.\n            Managers should obtain new values for row\n            creation in this table by reading\n            mplsTunnelIndexNext. When\n            the MPLS signalling protocol is rsvp(2) this value\n            SHOULD be equal to the value signaled in the\n            Tunnel Id of the Session object. When the MPLS\n            signalling protocol is crldp(3) this value\n            SHOULD be equal to the value signaled in the\n            LSP ID.')
mplsTunnelInstance = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 2, 1, 2), MplsTunnelInstanceIndex())
if mibBuilder.loadTexts: mplsTunnelInstance.setDescription('Uniquely identifies a particular instance of a\n            tunnel between a pair of ingress and egress LSRs.\n            It is useful to identify multiple instances of\n            tunnels for the purposes of backup and parallel\n            tunnels. When the MPLS signaling protocol is\n            rsvp(2) this value SHOULD be equal to the LSP Id\n            of the Sender Template object. When the signaling\n            protocol is crldp(3) there is no equivalent\n            signaling object.')
mplsTunnelIngressLSRId = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 2, 1, 3), MplsExtendedTunnelId())
if mibBuilder.loadTexts: mplsTunnelIngressLSRId.setDescription('Identity of the ingress LSR associated with this\n            tunnel instance. When the MPLS signalling protocol\n            is rsvp(2) this value SHOULD be equal to the Tunnel\n            Sender Address in the Sender Template object and MAY\n            be equal to the Extended Tunnel Id field in the\n            SESSION object. When the MPLS signalling protocol is\n            crldp(3) this value SHOULD be equal to the Ingress\n            LSR Router ID field in the LSPID TLV object.')
mplsTunnelEgressLSRId = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 2, 1, 4), MplsExtendedTunnelId())
if mibBuilder.loadTexts: mplsTunnelEgressLSRId.setDescription('Identity of the egress LSR associated with this\n            tunnel instance.')
mplsTunnelName = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 2, 1, 5), SnmpAdminString()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelName.setDescription("The canonical name assigned to the tunnel. This name\n            can be used to refer to the tunnel on the LSR's\n            console port.  If mplsTunnelIsIf is set to true\n            then the ifName of the interface corresponding to\n            this tunnel should have a value equal to\n            mplsTunnelName.  Also see the description of ifName\n            in RFC 2863.")
mplsTunnelDescr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 2, 1, 6), SnmpAdminString()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelDescr.setDescription('A textual string containing information about the\n            tunnel.  If there is no description this object\n            contains a zero length string. This object is may\n            not be signaled by MPLS signaling protocols,\n            consequentally the value of this object at transit\n            and egress LSRs MAY be automatically generated or\n            absent.')
mplsTunnelIsIf = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 2, 1, 7), TruthValue().clone('false')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelIsIf.setDescription('Denotes whether or not this tunnel corresponds to an\n            interface represented in the interfaces group\n            table. Note that if this variable is set to true\n            then the ifName of the interface corresponding to\n            this tunnel should have a value equal to\n            mplsTunnelName.  Also see the description of ifName\n            in RFC 2863.  This object is meaningful only at the\n            ingress and egress LSRs.')
mplsTunnelIfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 2, 1, 8), InterfaceIndexOrZero()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsTunnelIfIndex.setDescription('If mplsTunnelIsIf is set to true, then this value\n            contains the LSR-assigned ifIndex which corresponds\n            to an entry in the interfaces table.  Otherwise\n            this variable should contain the value of zero\n            indicating that a valid ifIndex was not assigned to\n            this tunnel interface.')
mplsTunnelOwner = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 2, 1, 9), MplsOwner()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsTunnelOwner.setDescription('Denotes the entity that created and is responsible\n            for managing this tunnel. This column is\n            automatically filled by the agent on creation of a\n            row.')
mplsTunnelRole = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 2, 1, 10), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("head", 1), ("transit", 2), ("tail", 3), ("headTail", 4),)).clone('head')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelRole.setDescription('This value signifies the role that this tunnel\n            entry/instance represents. This value MUST be set\n            to head(1) at the originating point of the tunnel.\n            This value MUST be set to transit(2) at transit\n            points along the tunnel, if transit points are\n            supported. This value MUST be set to tail(3) at the\n            terminating point of the tunnel if tunnel tails are\n            supported.\n\n            The value headTail(4) is provided for tunnels that\n            begin and end on the same LSR.')
mplsTunnelXCPointer = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 2, 1, 11), RowPointer().clone((0, 0))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelXCPointer.setDescription('This variable points to a row in the mplsXCTable.\n            This table identifies the segments that compose\n            this tunnel, their characteristics, and\n            relationships to each other. A value of zeroDotZero\n            indicates that no LSP has been associated with this\n            tunnel yet.')
mplsTunnelSignallingProto = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 2, 1, 12), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("none", 1), ("rsvp", 2), ("crldp", 3), ("other", 4),)).clone('none')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelSignallingProto.setDescription('The signalling protocol, if any, used to setup this\n            tunnel.')
mplsTunnelSetupPrio = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 2, 1, 13), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,7))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelSetupPrio.setDescription('Indicates the setup priority of this tunnel.')
mplsTunnelHoldingPrio = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 2, 1, 14), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,7))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelHoldingPrio.setDescription('Indicates the holding priority for this tunnel.')
mplsTunnelSessionAttributes = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 2, 1, 15), Bits().clone(namedValues=NamedValues(("fastReroute", 0), ("mergingPermitted", 1), ("isPersistent", 2), ("isPinned", 3), ("recordRoute", 4),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelSessionAttributes.setDescription('This bit mask indicates optional session values for\n            this tunnel. The following describes these bit\n            fields:\n\n            fastReroute  This flag indicates that the any tunnel\n            hop may choose to reroute this tunnel without\n            tearing it down.  This flag permits transit routers\n            to use a local repair mechanism which may result in\n            violation of the explicit routing of this tunnel.\n            When a fault is detected on an adjacent downstream\n            link or node, a transit router can re-route traffic\n            for fast service restoration.\n\n            mergingPermitted  This flag permits transit routers\n            to merge this session with other RSVP sessions for\n            the purpose of reducing resource overhead on\n            downstream transit routers, thereby providing\n            better network scaling.\n\n            isPersistent  Indicates whether this tunnel should\n            be restored automatically after a failure occurs.\n\n            isPinned  This flag indicates whether the loose-\n            routed hops of this tunnel are to be pinned.\n\n            recordRoute  This flag indicates whether or not the\n            signalling protocol should remember the tunnel path\n            after it has been signaled.')
mplsTunnelLocalProtectInUse = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 2, 1, 16), TruthValue().clone('false')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelLocalProtectInUse.setDescription('Indicates that the local repair mechanism is in use\n            to maintain this tunnel (usually in the face of an\n            outage of the link it was previously routed over).')
mplsTunnelResourcePointer = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 2, 1, 17), RowPointer().clone((0, 0))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelResourcePointer.setDescription('This variable represents a pointer to the traffic\n            parameter specification for this tunnel.  This\n            value may point at an entry in the\n            mplsTunnelResourceEntry to indicate which\n            mplsTunnelResourceEntry is to be assigned to this\n            LSP instance.  This value may optionally point at\n            an externally defined traffic parameter\n            specification table.  A value of zeroDotZero\n            indicates best-effort treatment.  By having the\n            same value of this object, two or more LSPs can\n            indicate resource sharing.')
mplsTunnelPrimaryInstance = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 2, 1, 18), MplsTunnelInstanceIndex()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsTunnelPrimaryInstance.setDescription('Specifies the instance index of the primary instance\n            of this tunnel. More details of the definition of\n            tunnel instances and the primary tunnel instance\n            can be found in the description of the TEXTUAL-CONVENTION\n            MplsTunnelInstanceIndex.')
mplsTunnelInstancePriority = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 2, 1, 19), Unsigned32()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelInstancePriority.setDescription('This value indicates which priority, in descending\n            order, with 0 indicating the lowest priority,\n            within a group of tunnel instances. A group of\n            tunnel instances is defined as a set of LSPs with\n            the same mplsTunnelIndex in this table, but with a\n            different mplsTunnelInstance. Tunnel instance\n            priorities are used to denote the priority at which\n            a particular tunnel instance will supercede\n            another. Instances of tunnels containing the same\n            mplsTunnelInstancePriority will be used for load\n            sharing.')
mplsTunnelHopTableIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 2, 1, 20), MplsPathIndexOrZero()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelHopTableIndex.setDescription('Index into the mplsTunnelHopTable entry that\n            specifies the explicit route hops for this tunnel.\n            This object is meaningful only at the head-end of\n            the tunnel.')
mplsTunnelPathInUse = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 2, 1, 21), MplsPathIndexOrZero()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelPathInUse.setDescription('This value denotes the configured path that was\n            chosen for this tunnel. This value reflects the\n            secondary index into mplsTunnelHopTable. This path\n            may not exactly match the one in\n            mplsTunnelARHopTable due to the fact that some CSPF\n            modification may have taken place. See\n            mplsTunnelARHopTable for the actual path being\n            taken by the tunnel. A value of zero denotes that\n            no path is currently in use or available.')
mplsTunnelARHopTableIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 2, 1, 22), MplsPathIndexOrZero()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsTunnelARHopTableIndex.setDescription('Index into the mplsTunnelARHopTable entry that\n            specifies the actual hops traversed by the tunnel.\n            This is automatically updated by the agent when the\n            actual hops becomes available.')
mplsTunnelCHopTableIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 2, 1, 23), MplsPathIndexOrZero()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsTunnelCHopTableIndex.setDescription('Index into the mplsTunnelCHopTable entry that\n            specifies the computed hops traversed by the\n            tunnel. This is automatically updated by the agent\n            when computed hops become available or when\n            computed hops get modified.')
mplsTunnelIncludeAnyAffinity = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 2, 1, 24), MplsTunnelAffinity()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelIncludeAnyAffinity.setDescription('A link satisfies the include-any constraint if and\n            only if the constraint is zero, or the link and the\n            constraint have a resource class in common.')
mplsTunnelIncludeAllAffinity = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 2, 1, 25), MplsTunnelAffinity()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelIncludeAllAffinity.setDescription('A link satisfies the include-all constraint if and\n            only if the link contains all of the administrative\n            groups specified in the constraint.')
mplsTunnelExcludeAnyAffinity = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 2, 1, 26), MplsTunnelAffinity()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelExcludeAnyAffinity.setDescription('A link satisfies the exclude-any constraint if and\n            only if the link contains none of the\n            administrative groups specified in the constraint.')
mplsTunnelTotalUpTime = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 2, 1, 27), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsTunnelTotalUpTime.setDescription('This value represents the aggregate up time for all\n            instances of this tunnel, if available. If this\n            value is unavailable, it MUST return a value of 0.')
mplsTunnelInstanceUpTime = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 2, 1, 28), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsTunnelInstanceUpTime.setDescription("This value identifies the total time that this\n            tunnel instance's operStatus has been Up(1).")
mplsTunnelPrimaryUpTime = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 2, 1, 29), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsTunnelPrimaryUpTime.setDescription('Specifies the total time the primary instance of\n            this tunnel has been active. The primary instance\n            of this tunnel is defined in\n            mplsTunnelPrimaryInstance.')
mplsTunnelPathChanges = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 2, 1, 30), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsTunnelPathChanges.setDescription('Specifies the number of times the actual path for\n            this tunnel instance has changed.')
mplsTunnelLastPathChange = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 2, 1, 31), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsTunnelLastPathChange.setDescription('Specifies the time since the last change to the\n            actual path for this tunnel instance.')
mplsTunnelCreationTime = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 2, 1, 32), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsTunnelCreationTime.setDescription('Specifies the value of SysUpTime when the first\n            instance of this tunnel came into existence.\n            That is, when the value of mplsTunnelOperStatus\n            was first set to up(1).')
mplsTunnelStateTransitions = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 2, 1, 33), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsTunnelStateTransitions.setDescription('Specifies the number of times the state\n            (mplsTunnelOperStatus) of this tunnel instance has\n            changed.')
mplsTunnelAdminStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 2, 1, 34), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("up", 1), ("down", 2), ("testing", 3),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelAdminStatus.setDescription('Indicates the desired operational status of this\n            tunnel.')
mplsTunnelOperStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 2, 1, 35), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7,))).clone(namedValues=NamedValues(("up", 1), ("down", 2), ("testing", 3), ("unknown", 4), ("dormant", 5), ("notPresent", 6), ("lowerLayerDown", 7),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsTunnelOperStatus.setDescription('Indicates the actual operational status of this\n            tunnel, which is typically but not limited to, a\n            function of the state of individual segments of\n            this tunnel.')
mplsTunnelRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 2, 1, 36), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelRowStatus.setDescription('This variable is used to create, modify, and/or\n            delete a row in this table.  When a row in this\n            table is in active(1) state, no objects in that row\n            can be modified by the agent except\n            mplsTunnelAdminStatus, mplsTunnelRowStatus and\n            mplsTunnelStorageType.')
mplsTunnelStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 2, 1, 37), StorageType().clone('volatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelStorageType.setDescription("The storage type for this tunnel entry.\n                     Conceptual rows having the value 'permanent'\n                     need not allow write-access to any columnar\n                     objects in the row.")
mplsTunnelHopListIndexNext = MibScalar((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 3), MplsPathIndexOrZero()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsTunnelHopListIndexNext.setDescription('This object contains an appropriate value to be used\n            for mplsTunnelHopListIndex when creating entries in\n            the mplsTunnelHopTable.  If the number of\n            unassigned entries is exhausted, a retrieval\n            operation will return a value of 0.  This object\n            may also return a value of 0 when the LSR is unable\n            to accept conceptual row creation, for example, if\n            the mplsTunnelHopTable is implemented as read-only.\n            To obtain the value of mplsTunnelHopListIndex for a\n            new entry in the mplsTunnelHopTable, the manager\n            issues a management protocol retrieval operation to\n            obtain the current value of mplsTunnelHopIndex.\n\n            When the SET is performed to create a row in the\n            mplsTunnelHopTable, the Command Responder (agent)\n            must determine whether the value is indeed still\n            unused; Two Network Management Applications may\n            attempt to create a row (configuration entry)\n            simultaneously and use the same value. If it is\n            currently unused, the SET succeeds and the Command\n            Responder (agent) changes the value of this object,\n            according to an implementation-specific algorithm.\n            If the value is in use, however, the SET fails.  The\n            Network Management Application must then re-read\n            this variable to obtain a new usable value.')
mplsTunnelHopTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 4), )
if mibBuilder.loadTexts: mplsTunnelHopTable.setDescription('The mplsTunnelHopTable is used to indicate the hops,\n            strict or loose, for an instance of an MPLS tunnel\n            defined in mplsTunnelTable, when it is established\n            via signalling, for the outgoing direction of the\n            tunnel. Thus at a transit LSR, this table contains\n            the desired path of the tunnel from this LSR\n            onwards. Each row in this table is indexed by\n            mplsTunnelHopListIndex which corresponds to a group\n            of hop lists or path options.  Each row also has a\n            secondary index mplsTunnelHopIndex, which indicates\n            a group of hops (also known as a path option).\n            Finally, the third index, mplsTunnelHopIndex\n            indicates the specific hop information for a path\n            option. In case we want to specify a particular\n            interface on the originating LSR of an outgoing\n            tunnel by which we want packets to exit the LSR,\n            we specify this as the first hop for this tunnel in\n            mplsTunnelHopTable.')
mplsTunnelHopEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 4, 1), ).setIndexNames((0, "MPLS-TE-STD-MIB", "mplsTunnelHopListIndex"), (0, "MPLS-TE-STD-MIB", "mplsTunnelHopPathOptionIndex"), (0, "MPLS-TE-STD-MIB", "mplsTunnelHopIndex"))
if mibBuilder.loadTexts: mplsTunnelHopEntry.setDescription('An entry in this table represents a tunnel hop.  An\n            entry is created by a network administrator for\n            signaled ERLSP set up by an MPLS signalling\n            protocol.')
mplsTunnelHopListIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 4, 1, 1), MplsPathIndex())
if mibBuilder.loadTexts: mplsTunnelHopListIndex.setDescription('Primary index into this table identifying a\n            particular explicit route object.')
mplsTunnelHopPathOptionIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 4, 1, 2), MplsPathIndex())
if mibBuilder.loadTexts: mplsTunnelHopPathOptionIndex.setDescription('Secondary index into this table identifying a\n            particular group of hops representing a particular\n            configured path. This is otherwise known as a path\n            option.')
mplsTunnelHopIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 4, 1, 3), MplsPathIndex())
if mibBuilder.loadTexts: mplsTunnelHopIndex.setDescription('Tertiary index into this table identifying a\n            particular hop.')
mplsTunnelHopAddrType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 4, 1, 4), TeHopAddressType().clone('ipv4')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelHopAddrType.setDescription("The Hop Address Type of this tunnel hop.\n\n                     The value of this object cannot be changed\n                     if the value of the corresponding\n                     mplsTunnelHopRowStatus object is 'active'.\n\n                     Note that lspid(5) is a valid option only\n                     for tunnels signaled via CRLDP.\n                     ")
mplsTunnelHopIpAddr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 4, 1, 5), TeHopAddress().clone(hexValue="00000000")).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelHopIpAddr.setDescription("The Tunnel Hop Address for this tunnel hop.\n\n                     The type of this address is determined by the\n                     value of the corresponding mplsTunnelHopAddrType.\n\n                     The value of this object cannot be changed\n                     if the value of the corresponding\n                     mplsTunnelHopRowStatus object is 'active'.\n                     ")
mplsTunnelHopIpPrefixLen = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 4, 1, 6), InetAddressPrefixLength().clone(32)).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelHopIpPrefixLen.setDescription('If mplsTunnelHopAddrType is set to ipv4(1) or\n                     ipv6(2), then this value will contain an\n                     appropriate prefix length for the IP address in\n                     object mplsTunnelHopIpAddr. Otherwise this value\n                     is irrelevant and should be ignored.\n                     ')
mplsTunnelHopAsNumber = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 4, 1, 7), TeHopAddressAS()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelHopAsNumber.setDescription('If mplsTunnelHopAddrType is set to asnumber(3), then\n            this value will contain the AS number of this hop.\n            Otherwise the agent should set this object to zero-\n            length string and the manager should ignore this.')
mplsTunnelHopAddrUnnum = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 4, 1, 8), TeHopAddressUnnum()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelHopAddrUnnum.setDescription('If mplsTunnelHopAddrType is set to unnum(4), then\n            this value will contain the interface identifier of\n            the unnumbered interface for this hop. This object\n            should be used in conjunction with\n            mplsTunnelHopIpAddress which would contain the LSR\n            Router ID in this case. Otherwise the agent should\n            set this object to zero-length string and the\n            manager should ignore this.')
mplsTunnelHopLspId = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 4, 1, 9), MplsLSPID()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelHopLspId.setDescription('If mplsTunnelHopAddrType is set to lspid(5), then\n            this value will contain the LSPID of a tunnel of\n            this hop. The present tunnel being configured is\n            tunneled through this hop (using label stacking).\n            This object is otherwise insignificant and should\n            contain a value of 0 to indicate this fact.')
mplsTunnelHopType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 4, 1, 10), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("strict", 1), ("loose", 2),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelHopType.setDescription("Denotes whether this tunnel hop is routed in a\n            strict or loose fashion. The value of this object\n            has no meaning if the mplsTunnelHopInclude object\n            is set to 'false'.")
mplsTunnelHopInclude = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 4, 1, 11), TruthValue().clone('true')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelHopInclude.setDescription("If this value is set to true, then this indicates\n            that this hop must be included in the tunnel's\n            path. If this value is set to 'false', then this hop\n            must be avoided when calculating the path for this\n            tunnel. The default value of this object is 'true',\n            so that by default all indicated hops are included\n            in the CSPF path computation. If this object is set\n            to 'false' the value of mplsTunnelHopType should be\n            ignored.")
mplsTunnelHopPathOptionName = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 4, 1, 12), SnmpAdminString()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelHopPathOptionName.setDescription('The description of this series of hops as they\n            relate to the specified path option. The\n            value of this object SHOULD be the same for\n            each hop in the series that comprises a\n            path option.')
mplsTunnelHopEntryPathComp = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 4, 1, 13), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("dynamic", 1), ("explicit", 2),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelHopEntryPathComp.setDescription('If this value is set to dynamic, then the user\n            should only specify the source and destination of\n            the path and expect that the CSPF will calculate\n            the remainder of the path.  If this value is set to\n            explicit, the user should specify the entire path\n            for the tunnel to take.  This path may contain\n            strict or loose hops.  Each hop along a specific\n            path SHOULD have this object set to the same value')
mplsTunnelHopRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 4, 1, 14), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelHopRowStatus.setDescription('This variable is used to create, modify, and/or\n            delete a row in this table.  When a row in this\n            table is in active(1) state, no objects in that row\n            can be modified by the agent except\n            mplsTunnelHopRowStatus and\n            mplsTunnelHopStorageType.')
mplsTunnelHopStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 4, 1, 15), StorageType().clone('volatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelHopStorageType.setDescription("The storage type for this Hop entry. Conceptual\n            rows having the value 'permanent' need not\n            allow write-access to any columnar objects\n            in the row.")
mplsTunnelResourceIndexNext = MibScalar((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 5), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647))).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsTunnelResourceIndexNext.setDescription('This object contains the next appropriate value to\n            be used for mplsTunnelResourceIndex when creating\n            entries in the mplsTunnelResourceTable. If the\n            number of unassigned entries is exhausted, a\n            retrieval operation will return a value of 0.  This\n            object may also return a value of 0 when the LSR is\n            unable to accept conceptual row creation, for\n            example, if the mplsTunnelTable is implemented as\n            read-only.  To obtain the mplsTunnelResourceIndex\n            value for a new entry, the manager must first issue\n            a management protocol retrieval operation to obtain\n            the current value of this object.\n\n            When the SET is performed to create a row in the\n            mplsTunnelResourceTable, the Command Responder\n            (agent) must determine whether the value is indeed\n            still unused; Two Network Management Applications\n            may attempt to create a row (configuration entry)\n            simultaneously and use the same value. If it is\n            currently unused, the SET succeeds and the Command\n            Responder (agent) changes the value of this object,\n            according to an implementation-specific algorithm.\n            If the value is in use, however, the SET fails.  The\n            Network Management Application must then re-read\n            this variable to obtain a new usable value.')
mplsTunnelResourceTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 6), )
if mibBuilder.loadTexts: mplsTunnelResourceTable.setDescription('The mplsTunnelResourceTable allows a manager to\n            specify which resources are desired for an MPLS\n            tunnel.  This table also allows several tunnels to\n            point to a single entry in this table, implying\n            that these tunnels should share resources.')
mplsTunnelResourceEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 6, 1), ).setIndexNames((0, "MPLS-TE-STD-MIB", "mplsTunnelResourceIndex"))
if mibBuilder.loadTexts: mplsTunnelResourceEntry.setDescription('An entry in this table represents a set of resources\n            for an MPLS tunnel.  An entry can be created by a\n            network administrator or by an SNMP agent as\n            instructed by any MPLS signalling protocol.\n            An entry in this table referenced by a tunnel instance\n            with zero mplsTunnelInstance value indicates a\n            configured set of resource parameter. An entry\n            referenced by a tunnel instance with a non-zero\n            mplsTunnelInstance reflects the in-use resource\n            parameters for the tunnel instance which may have\n            been negotiated or modified by the MPLS signaling\n            protocols.')
mplsTunnelResourceIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 6, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647)))
if mibBuilder.loadTexts: mplsTunnelResourceIndex.setDescription('Uniquely identifies this row.')
mplsTunnelResourceMaxRate = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 6, 1, 2), MplsBitRate()).setUnits('kilobits per second').setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelResourceMaxRate.setDescription('The maximum rate in bits/second.  Note that setting\n            mplsTunnelResourceMaxRate,\n            mplsTunnelResourceMeanRate, and\n            mplsTunnelResourceMaxBurstSize to 0 indicates best-\n            effort treatment.')
mplsTunnelResourceMeanRate = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 6, 1, 3), MplsBitRate()).setUnits('kilobits per second').setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelResourceMeanRate.setDescription('This object is copied into an instance of\n            mplsTrafficParamMeanRate in the\n            mplsTrafficParamTable. The OID of this table entry\n            is then copied into the corresponding\n            mplsInSegmentTrafficParamPtr.')
mplsTunnelResourceMaxBurstSize = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 6, 1, 4), MplsBurstSize()).setUnits('bytes').setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelResourceMaxBurstSize.setDescription('The maximum burst size in bytes.')
mplsTunnelResourceMeanBurstSize = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 6, 1, 5), MplsBurstSize()).setUnits('bytes').setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelResourceMeanBurstSize.setDescription('The mean burst size in bytes.  The implementations\n            which do not implement this variable must return\n            a noSuchObject exception for this object and must\n            not allow a user to set this object.')
mplsTunnelResourceExBurstSize = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 6, 1, 6), MplsBurstSize()).setUnits('bytes').setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelResourceExBurstSize.setDescription('The Excess burst size in bytes.  The implementations\n            which do not implement this variable must return\n            noSuchObject exception for this object and must\n            not allow a user to set this value.')
mplsTunnelResourceFrequency = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 6, 1, 7), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("unspecified", 1), ("frequent", 2), ("veryFrequent", 3),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelResourceFrequency.setDescription('The granularity of the availability of committed\n            rate.  The implementations which do not implement\n            this variable must return unspecified(1) for this\n            value and must not allow a user to set this value.')
mplsTunnelResourceWeight = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 6, 1, 8), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,255))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelResourceWeight.setDescription('The relative weight for using excess bandwidth above\n            its committed rate.  The value of 0 means that\n            weight is not applicable for the CR-LSP.')
mplsTunnelResourceRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 6, 1, 9), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelResourceRowStatus.setDescription('This variable is used to create, modify, and/or\n            delete a row in this table.  When a row in this\n            table is in active(1) state, no objects in that row\n            can be modified by the agent except\n            mplsTunnelResourceRowStatus and\n            mplsTunnelResourceStorageType.')
mplsTunnelResourceStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 6, 1, 10), StorageType().clone('volatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelResourceStorageType.setDescription("The storage type for this Hop entry. Conceptual\n            rows having the value 'permanent' need not\n            allow write-access to any columnar objects\n            in the row.")
mplsTunnelARHopTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 7), )
if mibBuilder.loadTexts: mplsTunnelARHopTable.setDescription('The mplsTunnelARHopTable is used to indicate the\n            hops for an MPLS tunnel defined in mplsTunnelTable,\n            as reported by the MPLS signalling protocol. Thus at\n            a transit LSR, this table (if the table is supported\n            and if the signaling protocol is recording actual\n            route information) contains the actual route of the\n            whole tunnel. If the signaling protocol is not\n            recording the actual route, this table MAY report\n            the information from the mplsTunnelHopTable or the\n            mplsTunnelCHopTable.\n\n            Each row in this table is indexed by\n            mplsTunnelARHopListIndex. Each row also has a\n            secondary index mplsTunnelARHopIndex, corresponding\n            to the next hop that this row corresponds to.\n\n            Please note that since the information necessary to\n            build entries within this table is not provided by\n            some MPLS signalling protocols, implementation of\n            this table is optional. Furthermore, since the\n            information in this table is actually provided by\n            the MPLS signalling protocol after the path has\n            been set-up, the entries in this table are provided\n            only for observation, and hence, all variables in\n            this table are accessible exclusively as read-\n            only.\n\n            Note also that the contents of this table may change\n            while it is being read because of re-routing\n            activities. A network administrator may verify that\n            the actual route read is consistent by reference to\n            the mplsTunnelLastPathChange object.')
mplsTunnelARHopEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 7, 1), ).setIndexNames((0, "MPLS-TE-STD-MIB", "mplsTunnelARHopListIndex"), (0, "MPLS-TE-STD-MIB", "mplsTunnelARHopIndex"))
if mibBuilder.loadTexts: mplsTunnelARHopEntry.setDescription('An entry in this table represents a tunnel hop.  An\n            entry is created by the agent for signaled ERLSP\n            set up by an MPLS signalling protocol.')
mplsTunnelARHopListIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 7, 1, 1), MplsPathIndex())
if mibBuilder.loadTexts: mplsTunnelARHopListIndex.setDescription('Primary index into this table identifying a\n            particular recorded hop list.')
mplsTunnelARHopIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 7, 1, 2), MplsPathIndex())
if mibBuilder.loadTexts: mplsTunnelARHopIndex.setDescription('Secondary index into this table identifying the\n            particular hop.')
mplsTunnelARHopAddrType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 7, 1, 3), TeHopAddressType().clone('ipv4')).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsTunnelARHopAddrType.setDescription('The Hop Address Type of this tunnel hop.\n\n            Note that lspid(5) is a valid option only\n            for tunnels signaled via CRLDP.')
mplsTunnelARHopIpAddr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 7, 1, 4), TeHopAddress().clone(hexValue="00000000")).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsTunnelARHopIpAddr.setDescription('The Tunnel Hop Address for this tunnel hop.\n\n            The type of this address is determined by the\n            value of the corresponding mplsTunnelARHopAddrType.\n            If mplsTunnelARHopAddrType is set to unnum(4),\n            then this value contains the LSR Router ID of the\n            unnumbered interface. Otherwise the agent SHOULD\n            set this object to the zero-length string and the\n            manager should ignore this object.')
mplsTunnelARHopAddrUnnum = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 7, 1, 5), TeHopAddressUnnum()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsTunnelARHopAddrUnnum.setDescription('If mplsTunnelARHopAddrType is set to unnum(4), then\n            this value will contain the interface identifier of\n            the unnumbered interface for this hop. This object\n            should be used in conjunction with\n            mplsTunnelARHopIpAddr which would contain the LSR\n            Router ID in this case. Otherwise the agent should\n            set this object to zero-length string and the\n            manager should ignore this.')
mplsTunnelARHopLspId = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 7, 1, 6), MplsLSPID()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsTunnelARHopLspId.setDescription('If mplsTunnelARHopAddrType is set to lspid(5), then\n            this value will contain the LSP ID of this hop.\n            This object is otherwise insignificant and should\n            contain a value of 0 to indicate this fact.')
mplsTunnelCHopTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 8), )
if mibBuilder.loadTexts: mplsTunnelCHopTable.setDescription('The mplsTunnelCHopTable is used to indicate the\n            hops, strict or loose, for an MPLS tunnel defined\n            in mplsTunnelTable, as computed by a constraint-\n            based routing protocol, based on the\n            mplsTunnelHopTable for the outgoing direction of\n            the tunnel. Thus at a transit LSR, this table (if\n            the table is supported) MAY contain the path\n            computed by the CSPF engine on (or on behalf of)\n            this LSR. Each row in this table is indexed by\n            mplsTunnelCHopListIndex.  Each row also has a\n            secondary index mplsTunnelCHopIndex, corresponding\n            to the next hop that this row corresponds to. In\n            case we want to specify a particular interface on\n            the originating LSR of an outgoing tunnel by which\n            we want packets to exit the LSR, we specify this as\n            the first hop for this tunnel in\n            mplsTunnelCHopTable.\n\n            Please note that since the information necessary to\n            build entries within this table may not be\n            supported by some LSRs, implementation of this\n            table is optional. Furthermore, since the\n            information in this table describes the path\n            computed by the CSPF engine the entries in this\n            table are read-only.')
mplsTunnelCHopEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 8, 1), ).setIndexNames((0, "MPLS-TE-STD-MIB", "mplsTunnelCHopListIndex"), (0, "MPLS-TE-STD-MIB", "mplsTunnelCHopIndex"))
if mibBuilder.loadTexts: mplsTunnelCHopEntry.setDescription('An entry in this table represents a tunnel hop.  An\n            entry in this table is created by a path\n            computation engine using CSPF techniques applied to\n            the information collected by routing protocols and\n            the hops specified in the corresponding\n            mplsTunnelHopTable.')
mplsTunnelCHopListIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 8, 1, 1), MplsPathIndex())
if mibBuilder.loadTexts: mplsTunnelCHopListIndex.setDescription('Primary index into this table identifying a\n            particular computed hop list.')
mplsTunnelCHopIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 8, 1, 2), MplsPathIndex())
if mibBuilder.loadTexts: mplsTunnelCHopIndex.setDescription('Secondary index into this table identifying the\n            particular hop.')
mplsTunnelCHopAddrType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 8, 1, 3), TeHopAddressType().clone('ipv4')).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsTunnelCHopAddrType.setDescription('The Hop Address Type of this tunnel hop.\n\n            Note that lspid(5) is a valid option only\n            for tunnels signaled via CRLDP.')
mplsTunnelCHopIpAddr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 8, 1, 4), TeHopAddress().clone(hexValue="00000000")).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsTunnelCHopIpAddr.setDescription('The Tunnel Hop Address for this tunnel hop.\n\n            The type of this address is determined by the\n            value of the corresponding mplsTunnelCHopAddrType.\n\n            If mplsTunnelCHopAddrType is set to unnum(4), then\n            this value will contain the LSR Router ID of the\n            unnumbered interface. Otherwise the agent should\n            set this object to the zero-length string and the\n            manager SHOULD ignore this object.')
mplsTunnelCHopIpPrefixLen = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 8, 1, 5), InetAddressPrefixLength().clone(32)).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsTunnelCHopIpPrefixLen.setDescription('If mplsTunnelCHopAddrType is set to ipv4(1) or\n             ipv6(2), then this value will contain an\n             appropriate prefix length for the IP address in\n             object mplsTunnelCHopIpAddr. Otherwise this value\n             is irrelevant and should be ignored.\n            ')
mplsTunnelCHopAsNumber = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 8, 1, 6), TeHopAddressAS()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsTunnelCHopAsNumber.setDescription('If mplsTunnelCHopAddrType is set to asnumber(3),\n            then this value will contain the AS number of this\n            hop. Otherwise the agent should set this object to\n            zero-length string and the manager should ignore\n            this.')
mplsTunnelCHopAddrUnnum = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 8, 1, 7), TeHopAddressUnnum()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsTunnelCHopAddrUnnum.setDescription('If mplsTunnelCHopAddrType is set to unnum(4), then\n            this value will contain the unnumbered interface\n            identifier of this hop. This object should be used\n            in conjunction with mplsTunnelCHopIpAddr which\n            would contain the LSR Router ID in this case.\n\n            Otherwise the agent should set this object to zero-\n            length string and the manager should ignore this.')
mplsTunnelCHopLspId = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 8, 1, 8), MplsLSPID()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsTunnelCHopLspId.setDescription('If mplsTunnelCHopAddrType is set to lspid(5), then\n            this value will contain the LSP ID of this hop.\n            This object is otherwise insignificant and should\n            contain a value of 0 to indicate this fact.')
mplsTunnelCHopType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 8, 1, 9), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("strict", 1), ("loose", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsTunnelCHopType.setDescription('Denotes whether this is tunnel hop is routed in a\n            strict or loose fashion.')
mplsTunnelPerfTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 9), )
if mibBuilder.loadTexts: mplsTunnelPerfTable.setDescription('This table provides per-tunnel instance MPLS\n            performance information.')
mplsTunnelPerfEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 9, 1), )
mplsTunnelEntry.registerAugmentions(("MPLS-TE-STD-MIB", "mplsTunnelPerfEntry"))
mplsTunnelPerfEntry.setIndexNames(*mplsTunnelEntry.getIndexNames())
if mibBuilder.loadTexts: mplsTunnelPerfEntry.setDescription('An entry in this table is created by the LSR for\n            every tunnel.  Its is an extension to\n            mplsTunnelEntry.')
mplsTunnelPerfPackets = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 9, 1, 1), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsTunnelPerfPackets.setDescription('Number of packets forwarded by the tunnel.\n            This object should represents the 32-bit\n            value of the least significant part of the\n            64-bit value if both mplsTunnelPerfHCPackets\n            is returned.')
mplsTunnelPerfHCPackets = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 9, 1, 2), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsTunnelPerfHCPackets.setDescription('High capacity counter for number of packets\n            forwarded by the tunnel. ')
mplsTunnelPerfErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 9, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsTunnelPerfErrors.setDescription('Number of packets dropped because of errors or for\n            other reasons.')
mplsTunnelPerfBytes = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 9, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsTunnelPerfBytes.setDescription('Number of bytes forwarded by the tunnel.\n            This object should represents the 32-bit\n            value of the least significant part of the\n            64-bit value if both mplsTunnelPerfHCBytes\n            is returned.')
mplsTunnelPerfHCBytes = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 9, 1, 5), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mplsTunnelPerfHCBytes.setDescription('High capacity counter for number of bytes forwarded\n            by the tunnel.')
mplsTunnelCRLDPResTable = MibTable((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 10), )
if mibBuilder.loadTexts: mplsTunnelCRLDPResTable.setDescription('The mplsTunnelCRLDPResTable allows a manager to\n            specify which CR-LDP-specific resources are desired\n            for an MPLS tunnel if that tunnel is signaled using\n            CR-LDP. Note that these attributes are in addition\n            to those specified in mplsTunnelResourceTable. This\n            table also allows several tunnels to point to a\n            single entry in this table, implying that these\n            tunnels should share resources.')
mplsTunnelCRLDPResEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 10, 1), ).setIndexNames((0, "MPLS-TE-STD-MIB", "mplsTunnelResourceIndex"))
if mibBuilder.loadTexts: mplsTunnelCRLDPResEntry.setDescription('An entry in this table represents a set of resources\n            for an MPLS tunnel established using CRLDP\n            (mplsTunnelSignallingProto equal to crldp (3)). An\n            entry can be created by a network administrator or\n            by an SNMP agent as instructed by any MPLS\n            signalling protocol.')
mplsTunnelCRLDPResMeanBurstSize = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 10, 1, 1), MplsBurstSize()).setUnits('bytes').setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelCRLDPResMeanBurstSize.setDescription('The mean burst size in bytes.')
mplsTunnelCRLDPResExBurstSize = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 10, 1, 2), MplsBurstSize()).setUnits('bytes').setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelCRLDPResExBurstSize.setDescription('The Excess burst size in bytes.')
mplsTunnelCRLDPResFrequency = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 10, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("unspecified", 1), ("frequent", 2), ("veryFrequent", 3),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelCRLDPResFrequency.setDescription('The granularity of the availability of committed\n            rate.')
mplsTunnelCRLDPResWeight = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 10, 1, 4), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,255))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelCRLDPResWeight.setDescription('The relative weight for using excess bandwidth above\n            its committed rate.  The value of 0 means that\n            weight is not applicable for the CR-LSP.')
mplsTunnelCRLDPResFlags = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 10, 1, 5), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,63))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelCRLDPResFlags.setDescription('The value of the 1 byte Flags conveyed as part of\n            the traffic parameters during the establishment of\n            the CRLSP. The bits in this object are to be\n            interpreted as follows.\n\n            +--+--+--+--+--+--+--+--+\n            | Res |F6|F5|F4|F3|F2|F1|\n            +--+--+--+--+--+--+--+--+\n\n            Res - These bits are reserved. Zero on transmission.\n            Ignored on receipt.\n            F1 - Corresponds to the PDR.\n            F2 - Corresponds to the PBS.\n            F3 - Corresponds to the CDR.\n            F4 - Corresponds to the CBS.\n            F5 - Corresponds to the EBS.\n            F6 - Corresponds to the Weight.\n\n            Each flag if is a Negotiable Flag corresponding to a\n            Traffic Parameter. The Negotiable Flag value zero\n            denotes Not Negotiable and value one denotes\n            Negotiable.')
mplsTunnelCRLDPResRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 10, 1, 6), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelCRLDPResRowStatus.setDescription('This variable is used to create, modify, and/or\n            delete a row in this table.  When a row in this\n            table is in active(1) state, no objects in that row\n            can be modified by the agent except\n            mplsTunnelCRLDPResRowStatus and\n            mplsTunnelCRLDPResStorageType.')
mplsTunnelCRLDPResStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 10, 1, 7), StorageType().clone('volatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mplsTunnelCRLDPResStorageType.setDescription("The storage type for this CR-LDP Resource entry.\n            Conceptual rows having the value 'permanent'\n            need not allow write-access to any columnar\n            objects in the row.")
mplsTunnelNotificationEnable = MibScalar((1, 3, 6, 1, 2, 1, 10, 166, 3, 2, 11), TruthValue().clone('false')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: mplsTunnelNotificationEnable.setDescription('If this object is true, then it enables the\n            generation of mplsTunnelUp and mplsTunnelDown\n            traps, otherwise these traps are not emitted.')
mplsTunnelUp = NotificationType((1, 3, 6, 1, 2, 1, 10, 166, 3, 0, 1)).setObjects(*(("MPLS-TE-STD-MIB", "mplsTunnelAdminStatus"), ("MPLS-TE-STD-MIB", "mplsTunnelOperStatus"),))
if mibBuilder.loadTexts: mplsTunnelUp.setDescription('This notification is generated when a\n            mplsTunnelOperStatus object for one of the\n            configured tunnels is about to leave the down state\n            and transition into some other state (but not into\n            the notPresent state).  This other state is\n            indicated by the included value of\n            mplsTunnelOperStatus.')
mplsTunnelDown = NotificationType((1, 3, 6, 1, 2, 1, 10, 166, 3, 0, 2)).setObjects(*(("MPLS-TE-STD-MIB", "mplsTunnelAdminStatus"), ("MPLS-TE-STD-MIB", "mplsTunnelOperStatus"),))
if mibBuilder.loadTexts: mplsTunnelDown.setDescription('This notification is generated when a\n            mplsTunnelOperStatus object for one of the\n            configured tunnels is about to enter the down state\n            from some other state (but not from the notPresent\n            state).  This other state is indicated by the\n            included value of mplsTunnelOperStatus.')
mplsTunnelRerouted = NotificationType((1, 3, 6, 1, 2, 1, 10, 166, 3, 0, 3)).setObjects(*(("MPLS-TE-STD-MIB", "mplsTunnelAdminStatus"), ("MPLS-TE-STD-MIB", "mplsTunnelOperStatus"),))
if mibBuilder.loadTexts: mplsTunnelRerouted.setDescription("This notification is generated when a tunnel is\n            rerouted. If the mplsTunnelARHopTable is used, then\n            this tunnel instance's entry in the\n            mplsTunnelARHopTable MAY contain the new path for\n            this tunnel some time after this trap is issued by\n            the agent.")
mplsTunnelReoptimized = NotificationType((1, 3, 6, 1, 2, 1, 10, 166, 3, 0, 4)).setObjects(*(("MPLS-TE-STD-MIB", "mplsTunnelAdminStatus"), ("MPLS-TE-STD-MIB", "mplsTunnelOperStatus"),))
if mibBuilder.loadTexts: mplsTunnelReoptimized.setDescription("This notification is generated when a tunnel is\n            reoptimized. If the mplsTunnelARHopTable is used,\n            then this tunnel instance's entry in the\n            mplsTunnelARHopTable MAY contain the new path for\n            this tunnel some time after this trap is issued by\n            the agent.")
mplsTeGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 3, 3, 1))
mplsTeCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166, 3, 3, 2))
mplsTeModuleFullCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 10, 166, 3, 3, 2, 1)).setObjects(*(("IF-MIB", "ifGeneralInformationGroup"), ("IF-MIB", "ifCounterDiscontinuityGroup"), ("MPLS-TE-STD-MIB", "mplsTunnelGroup"), ("MPLS-TE-STD-MIB", "mplsTunnelScalarGroup"), ("MPLS-TE-STD-MIB", "mplsTunnelManualGroup"), ("MPLS-TE-STD-MIB", "mplsTunnelSignaledGroup"), ("MPLS-TE-STD-MIB", "mplsTunnelIsNotIntfcGroup"), ("MPLS-TE-STD-MIB", "mplsTunnelIsIntfcGroup"), ("MPLS-TE-STD-MIB", "mplsTunnelCRLDPResOptionalGroup"), ("MPLS-TE-STD-MIB", "mplsTeNotificationGroup"),))
if mibBuilder.loadTexts: mplsTeModuleFullCompliance.setDescription('Compliance statement for agents that provide full\n            support the MPLS-TE-STD-MIB module.')
mplsTeModuleReadOnlyCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 10, 166, 3, 3, 2, 2)).setObjects(*(("MPLS-TE-STD-MIB", "mplsTunnelGroup"), ("MPLS-TE-STD-MIB", "mplsTunnelScalarGroup"), ("MPLS-TE-STD-MIB", "mplsTunnelManualGroup"), ("MPLS-TE-STD-MIB", "mplsTunnelSignaledGroup"), ("MPLS-TE-STD-MIB", "mplsTunnelIsNotIntfcGroup"), ("MPLS-TE-STD-MIB", "mplsTunnelIsIntfcGroup"), ("MPLS-TE-STD-MIB", "mplsTunnelCRLDPResOptionalGroup"), ("MPLS-TE-STD-MIB", "mplsTeNotificationGroup"),))
if mibBuilder.loadTexts: mplsTeModuleReadOnlyCompliance.setDescription('Compliance requirement for implementations that only\n            provide read-only support for MPLS-TE-STD-MIB.\n            Such devices can then be monitored but cannot be\n            configured using this MIB modules.')
mplsTunnelGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 166, 3, 3, 1, 1)).setObjects(*(("MPLS-TE-STD-MIB", "mplsTunnelIndexNext"), ("MPLS-TE-STD-MIB", "mplsTunnelName"), ("MPLS-TE-STD-MIB", "mplsTunnelDescr"), ("MPLS-TE-STD-MIB", "mplsTunnelOwner"), ("MPLS-TE-STD-MIB", "mplsTunnelXCPointer"), ("MPLS-TE-STD-MIB", "mplsTunnelIfIndex"), ("MPLS-TE-STD-MIB", "mplsTunnelHopTableIndex"), ("MPLS-TE-STD-MIB", "mplsTunnelARHopTableIndex"), ("MPLS-TE-STD-MIB", "mplsTunnelCHopTableIndex"), ("MPLS-TE-STD-MIB", "mplsTunnelAdminStatus"), ("MPLS-TE-STD-MIB", "mplsTunnelOperStatus"), ("MPLS-TE-STD-MIB", "mplsTunnelRowStatus"), ("MPLS-TE-STD-MIB", "mplsTunnelNotificationEnable"), ("MPLS-TE-STD-MIB", "mplsTunnelStorageType"), ("MPLS-TE-STD-MIB", "mplsTunnelConfigured"), ("MPLS-TE-STD-MIB", "mplsTunnelActive"), ("MPLS-TE-STD-MIB", "mplsTunnelPrimaryInstance"), ("MPLS-TE-STD-MIB", "mplsTunnelPrimaryUpTime"), ("MPLS-TE-STD-MIB", "mplsTunnelPathChanges"), ("MPLS-TE-STD-MIB", "mplsTunnelLastPathChange"), ("MPLS-TE-STD-MIB", "mplsTunnelCreationTime"), ("MPLS-TE-STD-MIB", "mplsTunnelStateTransitions"), ("MPLS-TE-STD-MIB", "mplsTunnelIncludeAnyAffinity"), ("MPLS-TE-STD-MIB", "mplsTunnelIncludeAllAffinity"), ("MPLS-TE-STD-MIB", "mplsTunnelExcludeAnyAffinity"), ("MPLS-TE-STD-MIB", "mplsTunnelPerfPackets"), ("MPLS-TE-STD-MIB", "mplsTunnelPerfHCPackets"), ("MPLS-TE-STD-MIB", "mplsTunnelPerfErrors"), ("MPLS-TE-STD-MIB", "mplsTunnelPerfBytes"), ("MPLS-TE-STD-MIB", "mplsTunnelPerfHCBytes"), ("MPLS-TE-STD-MIB", "mplsTunnelResourcePointer"), ("MPLS-TE-STD-MIB", "mplsTunnelInstancePriority"), ("MPLS-TE-STD-MIB", "mplsTunnelPathInUse"), ("MPLS-TE-STD-MIB", "mplsTunnelRole"), ("MPLS-TE-STD-MIB", "mplsTunnelTotalUpTime"), ("MPLS-TE-STD-MIB", "mplsTunnelInstanceUpTime"), ("MPLS-TE-STD-MIB", "mplsTunnelResourceIndexNext"), ("MPLS-TE-STD-MIB", "mplsTunnelResourceMaxRate"), ("MPLS-TE-STD-MIB", "mplsTunnelResourceMeanRate"), ("MPLS-TE-STD-MIB", "mplsTunnelResourceMaxBurstSize"), ("MPLS-TE-STD-MIB", "mplsTunnelResourceMeanBurstSize"), ("MPLS-TE-STD-MIB", "mplsTunnelResourceExBurstSize"), ("MPLS-TE-STD-MIB", "mplsTunnelResourceFrequency"), ("MPLS-TE-STD-MIB", "mplsTunnelResourceWeight"), ("MPLS-TE-STD-MIB", "mplsTunnelResourceRowStatus"), ("MPLS-TE-STD-MIB", "mplsTunnelResourceStorageType"), ("MPLS-TE-STD-MIB", "mplsTunnelARHopAddrType"), ("MPLS-TE-STD-MIB", "mplsTunnelARHopIpAddr"), ("MPLS-TE-STD-MIB", "mplsTunnelARHopAddrUnnum"), ("MPLS-TE-STD-MIB", "mplsTunnelARHopLspId"), ("MPLS-TE-STD-MIB", "mplsTunnelCHopAddrType"), ("MPLS-TE-STD-MIB", "mplsTunnelCHopIpAddr"), ("MPLS-TE-STD-MIB", "mplsTunnelCHopIpPrefixLen"), ("MPLS-TE-STD-MIB", "mplsTunnelCHopAsNumber"), ("MPLS-TE-STD-MIB", "mplsTunnelCHopAddrUnnum"), ("MPLS-TE-STD-MIB", "mplsTunnelCHopLspId"), ("MPLS-TE-STD-MIB", "mplsTunnelCHopType"),))
if mibBuilder.loadTexts: mplsTunnelGroup.setDescription('Necessary, but not sufficient, set of objects to\n            implement tunnels.  In addition, depending on the\n            type of the tunnels supported (for example,\n            manually configured or signaled, persistent or non-\n            persistent, etc.), the following other groups\n            defined below are mandatory: mplsTunnelManualGroup\n            and/or mplsTunnelSignaledGroup,\n            mplsTunnelIsNotIntfcGroup and/or\n            mplsTunnelIsIntfcGroup.')
mplsTunnelManualGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 166, 3, 3, 1, 2)).setObjects(*(("MPLS-TE-STD-MIB", "mplsTunnelSignallingProto"),))
if mibBuilder.loadTexts: mplsTunnelManualGroup.setDescription('Object(s) needed to implement manually configured\n            tunnels.')
mplsTunnelSignaledGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 166, 3, 3, 1, 3)).setObjects(*(("MPLS-TE-STD-MIB", "mplsTunnelSetupPrio"), ("MPLS-TE-STD-MIB", "mplsTunnelHoldingPrio"), ("MPLS-TE-STD-MIB", "mplsTunnelSignallingProto"), ("MPLS-TE-STD-MIB", "mplsTunnelLocalProtectInUse"), ("MPLS-TE-STD-MIB", "mplsTunnelSessionAttributes"), ("MPLS-TE-STD-MIB", "mplsTunnelHopListIndexNext"), ("MPLS-TE-STD-MIB", "mplsTunnelHopAddrType"), ("MPLS-TE-STD-MIB", "mplsTunnelHopIpAddr"), ("MPLS-TE-STD-MIB", "mplsTunnelHopIpPrefixLen"), ("MPLS-TE-STD-MIB", "mplsTunnelHopAddrUnnum"), ("MPLS-TE-STD-MIB", "mplsTunnelHopAsNumber"), ("MPLS-TE-STD-MIB", "mplsTunnelHopLspId"), ("MPLS-TE-STD-MIB", "mplsTunnelHopType"), ("MPLS-TE-STD-MIB", "mplsTunnelHopInclude"), ("MPLS-TE-STD-MIB", "mplsTunnelHopPathOptionName"), ("MPLS-TE-STD-MIB", "mplsTunnelHopEntryPathComp"), ("MPLS-TE-STD-MIB", "mplsTunnelHopRowStatus"), ("MPLS-TE-STD-MIB", "mplsTunnelHopStorageType"),))
if mibBuilder.loadTexts: mplsTunnelSignaledGroup.setDescription('Objects needed to implement signaled tunnels.')
mplsTunnelScalarGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 166, 3, 3, 1, 4)).setObjects(*(("MPLS-TE-STD-MIB", "mplsTunnelConfigured"), ("MPLS-TE-STD-MIB", "mplsTunnelActive"), ("MPLS-TE-STD-MIB", "mplsTunnelTEDistProto"), ("MPLS-TE-STD-MIB", "mplsTunnelMaxHops"), ("MPLS-TE-STD-MIB", "mplsTunnelNotificationMaxRate"),))
if mibBuilder.loadTexts: mplsTunnelScalarGroup.setDescription('Scalar object needed to implement MPLS tunnels.')
mplsTunnelIsIntfcGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 166, 3, 3, 1, 5)).setObjects(*(("MPLS-TE-STD-MIB", "mplsTunnelIsIf"),))
if mibBuilder.loadTexts: mplsTunnelIsIntfcGroup.setDescription('Objects needed to implement tunnels that are\n            interfaces.')
mplsTunnelIsNotIntfcGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 166, 3, 3, 1, 6)).setObjects(*(("MPLS-TE-STD-MIB", "mplsTunnelIsIf"),))
if mibBuilder.loadTexts: mplsTunnelIsNotIntfcGroup.setDescription('Objects needed to implement tunnels that are not\n            interfaces.')
mplsTunnelCRLDPResOptionalGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 166, 3, 3, 1, 7)).setObjects(*(("MPLS-TE-STD-MIB", "mplsTunnelCRLDPResMeanBurstSize"), ("MPLS-TE-STD-MIB", "mplsTunnelCRLDPResExBurstSize"), ("MPLS-TE-STD-MIB", "mplsTunnelCRLDPResFrequency"), ("MPLS-TE-STD-MIB", "mplsTunnelCRLDPResWeight"), ("MPLS-TE-STD-MIB", "mplsTunnelCRLDPResFlags"), ("MPLS-TE-STD-MIB", "mplsTunnelCRLDPResRowStatus"), ("MPLS-TE-STD-MIB", "mplsTunnelCRLDPResStorageType"),))
if mibBuilder.loadTexts: mplsTunnelCRLDPResOptionalGroup.setDescription('Set of objects implemented for resources applicable\n            for tunnels signaled using CR-LDP.')
mplsTeNotificationGroup = NotificationGroup((1, 3, 6, 1, 2, 1, 10, 166, 3, 3, 1, 8)).setObjects(*(("MPLS-TE-STD-MIB", "mplsTunnelUp"), ("MPLS-TE-STD-MIB", "mplsTunnelDown"), ("MPLS-TE-STD-MIB", "mplsTunnelRerouted"), ("MPLS-TE-STD-MIB", "mplsTunnelReoptimized"),))
if mibBuilder.loadTexts: mplsTeNotificationGroup.setDescription('Set of notifications implemented in this module.\n            None is mandatory.')
mibBuilder.exportSymbols("MPLS-TE-STD-MIB", mplsTunnelResourceIndexNext=mplsTunnelResourceIndexNext, mplsTunnelCRLDPResFlags=mplsTunnelCRLDPResFlags, mplsTunnelCRLDPResFrequency=mplsTunnelCRLDPResFrequency, mplsTunnelReoptimized=mplsTunnelReoptimized, mplsTunnelIfIndex=mplsTunnelIfIndex, mplsTeNotificationGroup=mplsTeNotificationGroup, mplsTunnelIncludeAnyAffinity=mplsTunnelIncludeAnyAffinity, mplsTunnelLocalProtectInUse=mplsTunnelLocalProtectInUse, mplsTunnelARHopLspId=mplsTunnelARHopLspId, mplsTunnelCHopEntry=mplsTunnelCHopEntry, mplsTeScalars=mplsTeScalars, mplsTunnelHopIpPrefixLen=mplsTunnelHopIpPrefixLen, mplsTunnelHopIpAddr=mplsTunnelHopIpAddr, mplsTunnelHopInclude=mplsTunnelHopInclude, mplsTunnelConfigured=mplsTunnelConfigured, mplsTunnelPerfHCBytes=mplsTunnelPerfHCBytes, mplsTunnelPathInUse=mplsTunnelPathInUse, mplsTunnelPerfEntry=mplsTunnelPerfEntry, mplsTunnelNotificationEnable=mplsTunnelNotificationEnable, mplsTeModuleReadOnlyCompliance=mplsTeModuleReadOnlyCompliance, mplsTeStdMIB=mplsTeStdMIB, mplsTunnelPrimaryInstance=mplsTunnelPrimaryInstance, mplsTunnelARHopAddrType=mplsTunnelARHopAddrType, mplsTunnelCreationTime=mplsTunnelCreationTime, mplsTunnelTEDistProto=mplsTunnelTEDistProto, mplsTunnelHopTable=mplsTunnelHopTable, mplsTunnelResourceEntry=mplsTunnelResourceEntry, mplsTunnelIsIntfcGroup=mplsTunnelIsIntfcGroup, mplsTunnelHopTableIndex=mplsTunnelHopTableIndex, mplsTunnelResourceExBurstSize=mplsTunnelResourceExBurstSize, mplsTunnelResourceRowStatus=mplsTunnelResourceRowStatus, mplsTunnelIngressLSRId=mplsTunnelIngressLSRId, mplsTunnelEgressLSRId=mplsTunnelEgressLSRId, mplsTunnelRowStatus=mplsTunnelRowStatus, mplsTunnelARHopAddrUnnum=mplsTunnelARHopAddrUnnum, mplsTunnelAdminStatus=mplsTunnelAdminStatus, mplsTunnelScalarGroup=mplsTunnelScalarGroup, mplsTunnelCRLDPResMeanBurstSize=mplsTunnelCRLDPResMeanBurstSize, mplsTunnelResourceTable=mplsTunnelResourceTable, mplsTunnelInstancePriority=mplsTunnelInstancePriority, mplsTunnelSignaledGroup=mplsTunnelSignaledGroup, mplsTunnelHopEntryPathComp=mplsTunnelHopEntryPathComp, mplsTunnelCHopAsNumber=mplsTunnelCHopAsNumber, mplsTunnelResourceMeanBurstSize=mplsTunnelResourceMeanBurstSize, mplsTunnelHopPathOptionName=mplsTunnelHopPathOptionName, mplsTunnelGroup=mplsTunnelGroup, mplsTunnelResourceIndex=mplsTunnelResourceIndex, mplsTunnelResourceStorageType=mplsTunnelResourceStorageType, mplsTunnelResourceMeanRate=mplsTunnelResourceMeanRate, mplsTunnelPerfPackets=mplsTunnelPerfPackets, mplsTunnelPerfHCPackets=mplsTunnelPerfHCPackets, mplsTunnelCRLDPResStorageType=mplsTunnelCRLDPResStorageType, mplsTunnelARHopIpAddr=mplsTunnelARHopIpAddr, mplsTunnelCHopListIndex=mplsTunnelCHopListIndex, mplsTunnelSetupPrio=mplsTunnelSetupPrio, mplsTunnelCRLDPResRowStatus=mplsTunnelCRLDPResRowStatus, mplsTunnelSessionAttributes=mplsTunnelSessionAttributes, mplsTunnelCHopIpPrefixLen=mplsTunnelCHopIpPrefixLen, mplsTunnelIndex=mplsTunnelIndex, mplsTunnelHoldingPrio=mplsTunnelHoldingPrio, mplsTunnelInstanceUpTime=mplsTunnelInstanceUpTime, mplsTeCompliances=mplsTeCompliances, mplsTunnelXCPointer=mplsTunnelXCPointer, mplsTunnelHopAddrType=mplsTunnelHopAddrType, mplsTeConformance=mplsTeConformance, mplsTunnelLastPathChange=mplsTunnelLastPathChange, mplsTunnelHopListIndex=mplsTunnelHopListIndex, mplsTunnelEntry=mplsTunnelEntry, mplsTunnelPrimaryUpTime=mplsTunnelPrimaryUpTime, mplsTunnelHopIndex=mplsTunnelHopIndex, mplsTunnelARHopListIndex=mplsTunnelARHopListIndex, mplsTunnelIsIf=mplsTunnelIsIf, mplsTunnelStorageType=mplsTunnelStorageType, mplsTunnelMaxHops=mplsTunnelMaxHops, mplsTunnelResourcePointer=mplsTunnelResourcePointer, mplsTunnelUp=mplsTunnelUp, mplsTunnelResourceMaxRate=mplsTunnelResourceMaxRate, mplsTunnelPerfTable=mplsTunnelPerfTable, mplsTunnelARHopIndex=mplsTunnelARHopIndex, mplsTunnelRole=mplsTunnelRole, mplsTunnelCRLDPResWeight=mplsTunnelCRLDPResWeight, mplsTunnelPerfErrors=mplsTunnelPerfErrors, mplsTunnelIncludeAllAffinity=mplsTunnelIncludeAllAffinity, mplsTeNotifications=mplsTeNotifications, mplsTunnelSignallingProto=mplsTunnelSignallingProto, mplsTunnelIsNotIntfcGroup=mplsTunnelIsNotIntfcGroup, mplsTeGroups=mplsTeGroups, mplsTeObjects=mplsTeObjects, mplsTunnelCRLDPResExBurstSize=mplsTunnelCRLDPResExBurstSize, mplsTunnelCHopAddrType=mplsTunnelCHopAddrType, mplsTunnelHopLspId=mplsTunnelHopLspId, mplsTunnelHopListIndexNext=mplsTunnelHopListIndexNext, mplsTunnelARHopEntry=mplsTunnelARHopEntry, mplsTunnelHopPathOptionIndex=mplsTunnelHopPathOptionIndex, mplsTunnelOwner=mplsTunnelOwner, mplsTunnelStateTransitions=mplsTunnelStateTransitions, mplsTunnelHopRowStatus=mplsTunnelHopRowStatus, mplsTunnelInstance=mplsTunnelInstance, mplsTunnelTotalUpTime=mplsTunnelTotalUpTime, mplsTunnelNotificationMaxRate=mplsTunnelNotificationMaxRate, mplsTunnelCHopTableIndex=mplsTunnelCHopTableIndex, mplsTunnelResourceMaxBurstSize=mplsTunnelResourceMaxBurstSize, mplsTunnelDescr=mplsTunnelDescr, mplsTunnelTable=mplsTunnelTable, mplsTunnelCHopIpAddr=mplsTunnelCHopIpAddr, mplsTunnelIndexNext=mplsTunnelIndexNext, mplsTunnelCHopIndex=mplsTunnelCHopIndex, mplsTunnelActive=mplsTunnelActive, mplsTunnelCHopType=mplsTunnelCHopType, mplsTunnelHopAddrUnnum=mplsTunnelHopAddrUnnum, PYSNMP_MODULE_ID=mplsTeStdMIB, mplsTunnelManualGroup=mplsTunnelManualGroup, mplsTunnelCHopTable=mplsTunnelCHopTable, mplsTunnelCHopAddrUnnum=mplsTunnelCHopAddrUnnum, mplsTunnelResourceFrequency=mplsTunnelResourceFrequency, mplsTeModuleFullCompliance=mplsTeModuleFullCompliance, mplsTunnelExcludeAnyAffinity=mplsTunnelExcludeAnyAffinity, mplsTunnelARHopTable=mplsTunnelARHopTable, mplsTunnelCRLDPResEntry=mplsTunnelCRLDPResEntry, mplsTunnelHopType=mplsTunnelHopType, mplsTunnelPerfBytes=mplsTunnelPerfBytes, mplsTunnelName=mplsTunnelName, mplsTunnelPathChanges=mplsTunnelPathChanges, mplsTunnelOperStatus=mplsTunnelOperStatus, mplsTunnelARHopTableIndex=mplsTunnelARHopTableIndex, mplsTunnelDown=mplsTunnelDown, mplsTunnelResourceWeight=mplsTunnelResourceWeight, mplsTunnelCHopLspId=mplsTunnelCHopLspId, mplsTunnelCRLDPResTable=mplsTunnelCRLDPResTable, mplsTunnelHopEntry=mplsTunnelHopEntry, mplsTunnelRerouted=mplsTunnelRerouted, mplsTunnelCRLDPResOptionalGroup=mplsTunnelCRLDPResOptionalGroup, mplsTunnelHopStorageType=mplsTunnelHopStorageType, mplsTunnelHopAsNumber=mplsTunnelHopAsNumber)
